@@ -3,7 +3,7 @@
 
 #include "Zend/zend_smart_str.h" /* for smart_string */
 
-#define PHP_MSGPACK_VERSION "2.0.2"
+#define PHP_MSGPACK_VERSION "2.1.0"
 
 extern zend_module_entry msgpack_module_entry;
 #define phpext_msgpack_ptr &msgpack_module_entry
@@ -41,7 +41,15 @@ ZEND_EXTERN_MODULE_GLOBALS(msgpack)
 
 PHP_MSGPACK_API void php_msgpack_serialize(
     smart_str *buf, zval *val);
-PHP_MSGPACK_API void php_msgpack_unserialize(
+PHP_MSGPACK_API int php_msgpack_unserialize(
     zval *return_value, char *str, size_t str_len);
 
+#ifdef WORDS_BIGENDIAN
+# define MSGPACK_ENDIAN_BIG_BYTE 1
+# define MSGPACK_ENDIAN_LITTLE_BYTE 0
+#else
+# define MSGPACK_ENDIAN_LITTLE_BYTE 1
+# define MSGPACK_ENDIAN_BIG_BYTE 0
+#endif
+
 #endif  /* PHP_MSGPACK_H */
